@@ -188,6 +188,17 @@ def find_first_free_name(prefix, exclude_names=(), start_at=2):
             i += 1
 
 
+def mk_mock_funcnode(arg, out):
+    @Sig(arg)
+    def func():
+        pass
+
+    # name = "_mock_" + str(arg) + "_" + str(out)  # f-string
+    name = f'_mock_{str(arg)}_{str(out)}'  # f-string
+
+    return FuncNode(func=func, out=out, name=name)
+
+
 def mk_func_name(func, exclude_names=()):
     name = getattr(func, '__name__', '')
     if name == '<lambda>':
@@ -922,10 +933,30 @@ class DAG:
             for k, v in self.graph.items()
         }
 
+    def __add__(self, other):
+        """A union of DAGs.
+
+        :param other: Another DAG or a valid object to make one with ``DAG(other)``.
+
+        >>> dag = DAG(list) + DAG(tuple)
+        >>> print(dag.synopsis_string(bind_info='hybrid'))
+        iterable -> tuple_ -> tuple
+        iterable -> list_ -> list
+        >>> dag([1,2,3])
+        ((1, 2, 3), [1, 2, 3])
+        """
+        if isinstance(other, DAG):
+            other = list(other.func_nodes)
+        else:
+            other = list(DAG(other).func_nodes)
+        return DAG(list(self.func_nodes) + other)
+
     # ------------ display --------------------------------------------------------------
 
-    def synopsis_string(self):
-        return '\n'.join(func_node.synopsis_string() for func_node in self.func_nodes)
+    def synopsis_string(self, bind_info='values'):
+        return '\n'.join(
+            func_node.synopsis_string(bind_info) for func_node in self.func_nodes
+        )
 
     # TODO: Give more control (merge with lined)
     def dot_digraph_body(self, start_lines=()):
@@ -1142,6 +1173,10 @@ def _add_new_line_if_none(s: str):
     return s
 
 
+def print_dag_string(dag: DAG, bind_info: str = 'hybrid'):
+    print(dag.synopsis_string(bind_info=bind_info))
+
+
 # ---------- with ext.gk -------------------------------------------------------
 
 with suppress(ModuleNotFoundError, ImportError):
@@ -1164,3 +1199,25 @@ with suppress(ModuleNotFoundError, ImportError):
 
         for func, operation in zip(funcs, funcs_to_operations(funcs, exclude_names)):
             yield operation(func)
+
+
+# reordering funcnodes
+from meshed.util import uncurry, pairs
+
+mk_mock_funcnode_from_tuple = uncurry(mk_mock_funcnode)
+
+
+def funcnodes_from_pairs(pairs):
+    return list(map(mk_mock_funcnode_from_tuple, pairs))
+
+
+def reorder_on_constraints(funcnodes, outs):
+    extra_nodes = funcnodes_from_pairs(pairs(outs))
+    funcnodes += extra_nodes
+    graph = _func_nodes_to_graph_dict(funcnodes)
+    nodes = topological_sort(graph)
+    print('after ordering:', nodes)
+    ordered_nodes = [node for node in nodes if node not in extra_nodes]
+    func_nodes, var_nodes = _separate_func_nodes_and_var_nodes(ordered_nodes)
+
+    return func_nodes, var_nodes
